@@ -178,5 +178,45 @@ speculate! {
             assert_eq!(::diff::lines("a", "b"), vec![::diff::Result::Left("a"),
                                                      ::diff::Result::Right("b")]);
         }
+
+        test "#6" {
+            // This produced an overflow in the lines computation because it
+            // was not accounting for the fact that the "right" length was
+            // less than the "left" length.
+            let expected = r#"
+BacktraceNode {
+    parents: [
+        BacktraceNode {
+            parents: []
+        },
+        BacktraceNode {
+            parents: [
+                BacktraceNode {
+                    parents: []
+                }
+            ]
+        }
+    ]
+}"#;
+            let actual = r#"
+BacktraceNode {
+    parents: [
+        BacktraceNode {
+            parents: []
+        },
+        BacktraceNode {
+            parents: [
+                BacktraceNode {
+                    parents: []
+                },
+                BacktraceNode {
+                    parents: []
+                }
+            ]
+        }
+    ]
+}"#;
+            ::diff::lines(actual, expected);
+        }
     }
 }
